@@ -69,7 +69,7 @@ macro_rules! match_options {
 /// | `#[example(ex)]` </br> `#[example = ex]`                                     | An example of the command's usage. May be called multiple times to add many examples at once.            | `ex` is a string                                                                                                                                                                                                                 |
 /// | `#[delimiters(delims)]`                                                      | Argument delimiters specific to this command. Overrides the global list of delimiters in the framework.  | `delims` is a comma separated list of strings |
 /// | `#[min_args(min)]` </br> `#[max_args(max)]` </br> `#[num_args(min_and_max)]` | The expected length of arguments that the command must receive in order to function correctly.           | `min`, `max` and `min_and_max` are 16-bit, unsigned integers.                                                                                                                                                                    |
-/// | `#[required_permissions(perms)]`                                             | Set of permissions the user must possess.                                                                | `perms` is a comma separated list of permission names.</br> These can be found at [Discord's official documentation](https://discord.com/developers/docs/topics/permissions).                                                 |
+/// | `#[required_permissions(perms)]`                                             | Set of permissions the user must possess. </br> In order for this attribute to work, "Presence Intent" and "Server Member Intent" options in bot application must be enabled and all intent flags must be enabled during client creation. | `perms` is a comma separated list of permission names.</br> These can be found at [Discord's official documentation](https://discord.com/developers/docs/topics/permissions).        |
 /// | `#[allowed_roles(roles)]`                                                    | Set of roles the user must possess.                                                                      | `roles` is a comma separated list of role names.                                                                                                                                                                                 |
 /// | `#[help_available]` </br> `#[help_available(b)]`                             | If the command should be displayed in the help message.                                                  | `b` is a boolean. If no boolean is provided, the value is assumed to be `true`.                                                                                                                                                  |
 /// | `#[only_in(ctx)]`                                                            | Which environment the command can be executed in.                                                        | `ctx` is a string with the accepted values `guild`/`guilds` and `dm`/`dms` (Direct Message).                                                                                                                                     |
@@ -104,7 +104,7 @@ pub fn command(attr: TokenStream, input: TokenStream) -> TokenStream {
     let _name = if !attr.is_empty() {
         parse_macro_input!(attr as Lit).to_str()
     } else {
-        fun.name.to_string()
+        fun.name.to_string_non_raw()
     };
 
     let mut options = Options::new();
@@ -596,7 +596,7 @@ pub fn help(attr: TokenStream, input: TokenStream) -> TokenStream {
 /// | `#[owner_privilege]` </br> `#[owner_privilege(b)]`   | If owners can bypass certain options.                                              | `b` is a boolean. If no boolean is provided, the value is assumed to be `true`.                                                                                                      |
 /// | `#[help_available]` </br> `#[help_available(b)]`     | If the group should be displayed in the help message.                              | `b` is a boolean. If no boolean is provided, the value is assumed to be `true`.                                                                                                      |
 /// | `#[checks(identifiers)]`                             | Preconditions that must met before the command's execution.                        | `identifiers` is a comma separated list of identifiers referencing functions marked by the `#[check]` macro                                                                          |
-/// | `#[required_permissions(perms)]`                     | Set of permissions the user must possess.                                          | `perms` is a comma separated list of permission names.</br> These can be found at [Discord's official documentation](https://discord.com/developers/docs/topics/permissions).        |
+/// | `#[required_permissions(perms)]`                     | Set of permissions the user must possess. </br> In order for this attribute to work, "Presence Intent" and "Server Member Intent" options in bot application must be enabled and all intent flags must be enabled during client creation. | `perms` is a comma separated list of permission names.</br> These can be found at [Discord's official documentation](https://discord.com/developers/docs/topics/permissions).        |
 /// | `#[default_command(cmd)]`                            | A command to execute if none of the group's prefixes are given.                    | `cmd` is an identifier referencing a function marked by the `#[command]` macro                                                                                                       |
 /// | `#[description(desc)]` </br> `#[description = desc]` | The group's description or summary.                                                | `desc` is a string describing the group.                                                                                                                                             |
 /// | `#[summary(desc)]` </br> `#[summary = desc]`         | A summary group description displayed when shown multiple groups.                  | `desc` is a string summaryly describing the group.                                                                                                                                   |
@@ -622,7 +622,7 @@ pub fn group(attr: TokenStream, input: TokenStream) -> TokenStream {
     let name = if !attr.is_empty() {
         parse_macro_input!(attr as Lit).to_str()
     } else {
-        group.name.to_string()
+        group.name.to_string_non_raw()
     };
 
     let mut options = GroupOptions::new();
@@ -832,9 +832,7 @@ pub fn check(_attr: TokenStream, input: TokenStream) -> TokenStream {
 /// use std::pin::Pin;
 ///
 /// fn foo(n: i32) -> Pin<Box<dyn std::future::Future<Output = i32>>> {
-///     Box::pin(async move {
-///         n + 4
-///     })
+///     Box::pin(async move { n + 4 })
 /// }
 /// ```
 ///
@@ -844,20 +842,14 @@ pub fn check(_attr: TokenStream, input: TokenStream) -> TokenStream {
 /// ```rust,no_run
 /// # #![feature(async_closure)]
 /// #
-/// async move |x: i32| {
-///     x * 2 + 4
-/// }
+/// async move |x: i32| x * 2 + 4
 /// # ;
 /// ```
 ///
 /// is changed to:
 ///
 /// ```rust,no_run
-/// |x: i32| {
-///     Box::pin(async move {
-///         x * 2 + 4
-///     })
-/// }
+/// |x: i32| Box::pin(async move { x * 2 + 4 })
 /// # ;
 /// ```
 ///
@@ -872,9 +864,7 @@ pub fn check(_attr: TokenStream, input: TokenStream) -> TokenStream {
 /// use std::pin::Pin;
 ///
 /// fn foo<'fut>(n: &'fut i32) -> Pin<Box<dyn std::future::Future<Output = i32> + 'fut>> {
-///     Box::pin(async move {
-///         *n + 4
-///     })
+///     Box::pin(async move { *n + 4 })
 /// }
 /// ```
 ///
